@@ -23,9 +23,12 @@
 # *  e-mail address 'scipion@cnb.csic.es'
 # *
 # **************************************************************************
+from pyworkflow.utils import weakImport
 
 from .protocol_ctffind import CistemProtCTFFind
-from .protocol_ts_ctffind import CistemProtTsCtffind
 from .protocol_unblur import CistemProtUnblur
 from .protocol_picking import CistemProtFindParticles
 from .protocol_refine2d import CistemProtRefine2D
+
+with weakImport('tomo'):
+    from .protocol_ts_ctffind import CistemProtTsCtffind
